==> ebus-0.1.2.tar.gz: ebus-0.1.2/setup.py <==
#    Copyright (C) 2015 abi <abi@singiro.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

from setuptools import setup
import ebus

from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='ebus',
    description='ebus - Event bus',
    version=ebus.__version__,
    long_description_content_type="text/markdown",
    long_description=long_description,
    author='Abi',
    author_email='abi@singiro.com',
    url='https://github.com/ebus',
    download_url='https://github.com/ebus/0.1.0.tar.gz',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
    ],
    keywords='event bus',
    license='MIT',
    packages=['ebus'],
    platforms='any',
)

==> ebus-0.1.3.tar.gz: ebus-0.1.3/setup.py <==
#    Copyright (C) 2015 abi <abi@singiro.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

from setuptools import setup
import ebus

from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='ebus',
    description='ebus - Event bus',
    version=ebus.__version__,
    long_description_content_type="text/markdown",
    long_description=long_description,
    author='Abi',
    author_email='abi@singiro.com',
    url='https://github.com/abisxir/ebus',
    download_url='https://github.com/abisxir/ebus/0.1.3.tar.gz',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
    ],
    keywords='event bus',
    license='MIT',
    packages=['ebus'],
    platforms='any',
)
